@@ -17,14 +17,16 @@ if __name__ == '__main__':
     data = df['ART-125.0Hz'].dropna()
 
     p = Pressure.from_pandas(data)
+    print(f'{p.samplerate} Hz')
     feet = data.iloc[p.feet]
-    # dics = data.iloc[p.dicrotic_offsets]
+    dics = data.iloc[p.dicrotic_offsets]
     sqi = p.calc_sqi()
     ssqi = pd.Series(p.calc_sqi(), index=data.index[p.diastolic_offsets])
     ssqi = ssqi[p.diastolic_offsets != 0]
+    print(p.calc_nra())
 
     plt.plot(data.index, data.values, '-')
     plt.plot(ssqi.index, ssqi.values * 100, '-')
     plt.plot(feet.index, feet.values, 'o')
-    # plt.plot(dics.index, dics.values, 'o')
+    plt.plot(dics.index, dics.values, '2')
     plt.show()
